DEFAULT_GEASE_FILE_NAME = '.gease'
DEFAULT_RELEASE_MESSAGE = "A new release via gease."
NOT_ENOUGH_ARGS = 'Not enough arguments'
KEY_GEASE_USER = 'user'
KEY_GEASE_TOKEN = 'personal_access_token'
MESSAGE_FMT_RELEASED = 'Release is created at: %s'
